@@ -178,9 +178,9 @@ class CreateDPDShipping(Wizard):
     def shipping_party(self, party, address):
         shipping_party = {
             'name1': party.name[:50],
-            'name2': address.name[:35] if address.name else party.name[:35],
+            'name2': address.party.name[:35] if party != address.party else '',
             'street': ' '.join((address.street or '').splitlines())[:35],
-            'country': address.country.code,
+            'country': address.country.code if address.country else '',
             'zipCode': address.zip[:9],
             'city': address.city[:50],
             }
